@@ -32,12 +32,6 @@ class Widget:
     def convert(self):
         layout = ""
 
-        if self.justify:
-            layout += f"@justify {self.justify}\n"
-
-        if self.fontsize:
-            layout += f"@fontsize {self.fontsize}\n"
-
         layout += f"{self.typ}:{self.id} {self.x} {self.y} {self.width} {self.height} "
 
         if self.typ == "range":
@@ -50,6 +44,14 @@ class Widget:
 
         if "\n" in self.value:
             layout = "[" + layout + "]"
+        
+        if self.justify:
+            layout = f"@justify {self.justify}\n{layout}"
+
+        if self.fontsize:
+            layout = f"@fontsize {self.fontsize}\n{layout}"
+            
+        print(layout)
 
         return layout
 
@@ -95,16 +97,24 @@ class ReMarkable:
     def display(self) -> bytes | dict:
         if not self.screen:
             return {}
-
-        script = f"@fontsize {self.fontsize}\n"
+        
+        script = ""
 
         if self.timeout:
             script += f"@timeout {self.timeout}\n"
 
         layout = []
+        
         for widget in self.screen:
+            
             compiled_widget = copy.copy(widget)
-
+            
+            if compiled_widget.fontsize is None:
+                layout.append(f"@fontsize {self.fontsize}")
+                
+            if compiled_widget.justify is None:
+                layout.append(f"@justify {self.justify}")
+                
             if {widget.width, widget.height} == {None}:
                 (
                     compiled_widget.width,
@@ -121,11 +131,6 @@ class ReMarkable:
 
             layout.append(compiled_widget.convert)
 
-            if compiled_widget.fontsize:
-                layout.append(f"@fontsize {self.fontsize}")
-            if compiled_widget.justify:
-                layout.append(f"@justify {self.justify}")
-
         script += "\n".join(layout)
 
         if self.debug:
